[jbosstools-commits] JBoss Tools SVN: r43485 - in workspace/akazakov/db: org.jboss.tools.cdi.db/.settings and 3 other directories.

jbosstools-commits at lists.jboss.org jbosstools-commits at lists.jboss.org
Thu Sep 6 18:59:09 EDT 2012


Author: akazakov
Date: 2012-09-06 18:59:09 -0400 (Thu, 06 Sep 2012)
New Revision: 43485

Added:
   workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/
   workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/org.eclipse.jdt.core.prefs
Modified:
   workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/CDIDbPlugin.java
   workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/BeanEntity.java
   workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/TypeEntity.java
   workspace/akazakov/db/org.jboss.tools.common.db/.classpath
Log:
https://issues.jboss.org/browse/JBIDE-12446

Added: workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/org.eclipse.jdt.core.prefs
===================================================================
--- workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/org.eclipse.jdt.core.prefs	                        (rev 0)
+++ workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/org.eclipse.jdt.core.prefs	2012-09-06 22:59:09 UTC (rev 43485)
@@ -0,0 +1,7 @@
+eclipse.preferences.version=1
+org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled
+org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.6
+org.eclipse.jdt.core.compiler.compliance=1.6
+org.eclipse.jdt.core.compiler.problem.assertIdentifier=error
+org.eclipse.jdt.core.compiler.problem.enumIdentifier=error
+org.eclipse.jdt.core.compiler.source=1.6


Property changes on: workspace/akazakov/db/org.jboss.tools.cdi.db/.settings/org.eclipse.jdt.core.prefs
___________________________________________________________________
Added: svn:mime-type
   + text/plain

Modified: workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/CDIDbPlugin.java
===================================================================
--- workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/CDIDbPlugin.java	2012-09-06 22:54:04 UTC (rev 43484)
+++ workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/CDIDbPlugin.java	2012-09-06 22:59:09 UTC (rev 43485)
@@ -28,15 +28,22 @@
 	 * (non-Javadoc)
 	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
 	 */
+	@Override
 	public void start(BundleContext bundleContext) throws Exception {
 		super.start(bundleContext);
         Display.getDefault().asyncExec(new Runnable() {
+        	@Override
         	public void run() {
 				try {
 					CDIDBManager.getInstance().start();
-				} catch (InstantiationException | IllegalAccessException
-						| ClassNotFoundException | SQLException e) {
+				} catch (InstantiationException e) {
 					logError(e);
+				} catch (ClassNotFoundException e) {
+					logError(e);
+				} catch (SQLException e) {
+					logError(e);
+				} catch (IllegalAccessException e) {
+					logError(e);
 				}
         	}
         });
@@ -46,6 +53,7 @@
 	 * (non-Javadoc)
 	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
 	 */
+	@Override
 	public void stop(BundleContext bundleContext) throws Exception {
 		CDIDBManager.getInstance().stop();
 		super.stop(bundleContext);

Modified: workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/BeanEntity.java
===================================================================
--- workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/TypeEntity.java	2012-09-06 22:54:04 UTC (rev 43484)
+++ workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/TypeEntity.java	2012-09-06 22:59:09 UTC (rev 43485)
@@ -10,9 +10,43 @@
  ******************************************************************************/ 
 package org.jboss.tools.cdi.db.entity;
 
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.GeneratedValue;
+import javax.persistence.Id;
+
 /**
  * @author Alexey Kazakov
  */
+ at Entity
 public class TypeEntity {
 
+	private long id;
+	private long index;
+
+	/**
+	 * @return the id
+	 */
+	@Id
+	@GeneratedValue
+	@Column
+	public long getId() {
+		return id;
+	}
+
+	/**
+	 * @param id the id to set
+	 */
+	public void setId(long id) {
+		this.id = id;
+	}
+
+	@Column
+	public long getIndex() {
+		return index;
+	}
+
+	public void setIndex(long index) {
+		this.index = index;
+	}
 }
\ No newline at end of file

Modified: workspace/akazakov/db/org.jboss.tools.common.db/.classpath
===================================================================
--- workspace/akazakov/db/org.jboss.tools.common.db/.classpath	2012-09-06 22:54:04 UTC (rev 43484)
+++ workspace/akazakov/db/org.jboss.tools.common.db/.classpath	2012-09-06 22:59:09 UTC (rev 43485)
@@ -3,22 +3,22 @@
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-1.6"/>
 	<classpathentry kind="con" path="org.eclipse.pde.core.requiredPlugins"/>
 	<classpathentry kind="src" path="src"/>
-	<classpathentry kind="lib" path="lib/derby.jar"/>
-	<classpathentry kind="lib" path="lib/derbyclient.jar"/>
-	<classpathentry kind="lib" path="lib/derbynet.jar"/>
-	<classpathentry kind="lib" path="lib/derbytools.jar"/>
-	<classpathentry kind="lib" path="lib/antlr-2.7.7.jar"/>
-	<classpathentry kind="lib" path="lib/dom4j-1.6.1.jar"/>
-	<classpathentry kind="lib" path="lib/hibernate-commons-annotations-4.0.1.Final.jar"/>
-	<classpathentry kind="lib" path="lib/hibernate-core-4.1.6.Final.jar"/>
-	<classpathentry kind="lib" path="lib/hibernate-entitymanager-4.1.6.Final.jar" sourcepath="/home/igels/Downloads/Java/JBoss/Hibernate/hibernate-release-4.1.6.Final/project"/>
-	<classpathentry kind="lib" path="lib/hibernate-jpa-2.0-api-1.0.1.Final.jar" sourcepath="/home/igels/Downloads/Java/JBoss/Hibernate/geronimo-jpa_2.0_spec-1.1-sources.jar">
+	<classpathentry exported="true" kind="lib" path="lib/derby.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/derbyclient.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/derbynet.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/derbytools.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/antlr-2.7.7.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/dom4j-1.6.1.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/hibernate-commons-annotations-4.0.1.Final.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/hibernate-core-4.1.6.Final.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/hibernate-entitymanager-4.1.6.Final.jar" sourcepath="/home/igels/Downloads/Java/JBoss/Hibernate/hibernate-release-4.1.6.Final/project"/>
+	<classpathentry exported="true" kind="lib" path="lib/hibernate-jpa-2.0-api-1.0.1.Final.jar" sourcepath="/home/igels/Downloads/Java/JBoss/Hibernate/geronimo-jpa_2.0_spec-1.1-sources.jar">
 		<attributes>
 			<attribute name="javadoc_location" value="jar:file:/home/igels/Downloads/Java/JBoss/Hibernate/geronimo-jpa_2.0_spec-1.1-javadoc.jar!/"/>
 		</attributes>
 	</classpathentry>
-	<classpathentry kind="lib" path="lib/javassist-3.15.0-GA.jar"/>
-	<classpathentry kind="lib" path="lib/jboss-logging-3.1.0.GA.jar"/>
-	<classpathentry kind="lib" path="lib/jboss-transaction-api_1.1_spec-1.0.0.Final.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/javassist-3.15.0-GA.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/jboss-logging-3.1.0.GA.jar"/>
+	<classpathentry exported="true" kind="lib" path="lib/jboss-transaction-api_1.1_spec-1.0.0.Final.jar"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>



More information about the jbosstools-commits mailing list
--- workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/BeanEntity.java	2012-09-06 22:54:04 UTC (rev 43484)
+++ workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/BeanEntity.java	2012-09-06 22:59:09 UTC (rev 43485)
@@ -10,16 +10,23 @@
  ******************************************************************************/ 
 package org.jboss.tools.cdi.db.entity;
 
+import java.util.List;
+
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.GeneratedValue;
+import javax.persistence.Id;
+
 /**
  * @author Alexey Kazakov
  */
 @Entity
 public class BeanEntity {
 
-	private static final long serialVersionUID = 1L;
-
 	private long id;
-	private String name;
+	private long index;
+	private List<TypeEntity> types;
+	private List<TypeEntity> qualifiers;
 
 	/**
 	 * @return the id
@@ -38,18 +45,40 @@
 		this.id = id;
 	}
 
+	@Column
+	public long getIndex() {
+		return index;
+	}
+
+	public void setIndex(long index) {
+		this.index = index;
+	}
+
 	/**
-	 * @return the name
+	 * @return the types
 	 */
-	@Column
-	public String getName() {
-		return name;
+	public List<TypeEntity> getTypes() {
+		return types;
 	}
 
 	/**
 	 * @param name the name to set
 	 */
-	public void setName(String name) {
-		this.name = name;
+	public void setTypes(List<TypeEntity> types) {
+		this.types = types;
 	}
+
+	/**
+	 * @return the qualifiers
+	 */
+	public List<TypeEntity> getQualifiers() {
+		return qualifiers;
+	}
+
+	/**
+	 * @param qualifiers the qualifiers to set
+	 */
+	public void setQualifiers(List<TypeEntity> qualifiers) {
+		this.qualifiers = qualifiers;
+	}
 }
\ No newline at end of file
@@ -38,18 +45,40 @@
 
 	/**
-	 * @param name the name to set
+	 * @param types the types to set
 	 */

Modified: workspace/akazakov/db/org.jboss.tools.cdi.db/src/org/jboss/tools/cdi/db/entity/TypeEntity.java
===================================================================